<?php

//
// innovaphone fax config PHP class
// copyright (c) innovaphone 2012 - 2014
//
// uses pear Config package
//

require_once('include_main.php');
require_once('innovaphone.fax.database.class.php');

tl::register("faxserveruser", dirname(__FILE__) . "\\..\\lang");

class FaxConfig
{
    const dbName = "innovaphone-faxserver";
    const dbUser = "innovaphone-faxserver";
    const dbPassword = "";
    const webdavPath = "/var/www/innovaphone/webdav/faxserver";
    const scriptPath = "/var/www/innovaphone/apps/innovaphone-faxserver/scripts";
    const logPath = "/var/www/innovaphone/apps/innovaphone-faxserver/log";
    const documentPath = "/var/www/innovaphone/apps/innovaphone-faxserver/tmp";
    const tmpPath = "/var/www/innovaphone/apps/innovaphone-faxserver/tmp";
    const coverPath = "/var/www/innovaphone/apps/innovaphone-faxserver/covers";
    const coverDefaultName = "innovaphone-default.odt";
    const coverDefault = "/var/www/innovaphone/apps/innovaphone-faxserver/innovaphone-default.odt";
}

class FaxLocation
{
    var $name = "";
    var $lang = "en";
    var $cover = "";
    
    public function FaxLocation($name, $lang = "en", $cover = "") {
        $this->name = $name;
        $this->lang = $lang;
        $this->cover = $cover;
    }
}

class FaxServerStrings
{
    const msgHeaderLine                 = 0;
    const msgSubjectDeliverSuccess      = 1;
    const msgSubjectDeliverError        = 2;
    const msgSubjectIncomingSuccess     = 3;
    const msgSubjectError               = 4;
    const msgSubjectErrorIncoming       = 5;
    const msgIncomingSuccess            = 6;
    const msgDeliverSuccess             = 7;
    const msgDeliverError               = 8;
    const msgDeliverErrorTimeout        = 9;
    const msgDeliverErrorNoFaxDevice    = 10;
    const msgDeliverErrorBusy           = 11;
    const msgError                      = 12;
    const msgErrorRightsNoUser          = 13;
    const msgErrorRightsNoLicense       = 14;
    const msgErrorRightsCheckFailed     = 15;
    const msgErrorNoFaxRecipients       = 16;
    const msgErrorCommand               = 17;
    const msgErrorJodconverter          = 18;
    const msgErrorUnoconv               = 19;
    const msgErrorGhostscript           = 20;
    const msgErrorCp                    = 21;
    const msgErrorZip                   = 22;
    const msgErrorNoAttachment          = 23;
    const msgErrorReadAttachment        = 24;
    const msgErrorMailSend              = 25;
    const msgErrorIncoming              = 26;
    const msgErrorOpenOffice            = 27;
    const msgErrorNoEmailAddress        = 28;
    const msgUnknownUser                = 29;
    const msgDeliverErrorCanceled       = 30;
    const msgHeaderLineLongCompanyName  = 31;
    
    public static function getStringIds()
    {
        $reflect = new ReflectionClass(get_class(new FaxServerStrings()));
        return $reflect->getConstants();
    }
    
    public static function getString($id) {
        $ret = "";
        switch($id) {
            case self::msgHeaderLine:
              $ret = tl::tl(
                /* Default fax document header line, <subscriber-name> is a field and must not be changed.
                The header line has 108 signs.
                Place holders for date and time:
                    $d: day of month, two digits
                    $j: day of month without leading zero
                    $m: month, two digits
                    $n: month without leading zero
                    $Y: year, four digits
                    $y: year, two digits
                    $G: hour, 24 hours format, without leading zero
                    $H: hour, 24 hours format, two digits
                    $i: minutes, two digits
                    $s: seconds, two digits
                    $p: number of page
                    $P: page count, if available, with leading '/'
                    $I: subscriber id
                    $R: remote subscriber id
                    $$: the sign '$'
                    $t: tabulator to the next 15 character grid
                    $c: text is centred

                Flags for the place folders:
                   0-9: field length, with tabulator jump forward to this position        
                   -:   left aligned
                */
                "\$d/\$m/\$Y  \$G:\$i   <subscriber-name>   \$I\$63t To:\$-20R\$tPage: \$p\$P\$c");
                break;
                
            case self::msgHeaderLineLongCompanyName:
                $ret = tl::tl(
                  /* Default fax document header line with a long customer company name, <subscriber-name> is a field and must not be changed.
                  The header line has 108 signs.
                  Place holders for date and time:
                      $d: day of month, two digits
                      $j: day of month without leading zero
                      $m: month, two digits
                      $n: month without leading zero
                      $Y: year, four digits
                      $y: year, two digits
                      $G: hour, 24 hours format, without leading zero
                      $H: hour, 24 hours format, two digits
                      $i: minutes, two digits
                      $s: seconds, two digits
                      $p: number of page
                      $P: page count, if available, with leading '/'
                      $I: subscriber id
                      $R: remote subscriber id
                      $$: the sign '$'
                      $t: tabulator to the next 15 character grid
                      $c: text is centred

                  Flags for the place folders:
                     0-9: field length, with tabulator jump forward to this position        
                     -:   left aligned
                   */
                  "\$d/\$m/\$Y  \$G:\$i   <subscriber-name>   \$I\$89t Page: \$p\$P\$c");
                break;

            case self::msgSubjectDeliverSuccess:
                $ret = tl::tl(/*no translation of <remote-number>, <subject> */"Fax sent successfully to <remote-number>: <subject>");
                break;
                
            case self::msgSubjectDeliverError:
                $ret = tl::tl(/*no translation of <remote-number>, <subject> */"Fax not sent to <remote-number>: <subject>");
                break;
                
            case self::msgSubjectIncomingSuccess:
                $ret = tl::tl(/*no translation of <remote-subscriber-id> */"Incoming fax document from '<remote-subscriber-id>'");
                break;

            case self::msgSubjectError:
                $ret = tl::tl("Failed incoming fax document");
                break;

            case self::msgSubjectErrorIncoming:
                $ret = tl::tl("Failed incoming fax document");
                break;

            case self::msgIncomingSuccess:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*no translation of <remote-number>; Dear user,...*/"you have received a fax document from <remote-number>.")."\n\n" .
                    tl::tl(/*no translation of <date>*/"Date <date>")."\n" .
                    tl::tl(/*no translation of <time>*/"Time <time>")."\n" .
                    tl::tl(/*no translation of <remote-subscriber-id>*/"Sender subscriber ID: <remote-subscriber-id>")."\n" .
                    tl::tl(/*no translation of <pages>*/"Pages: <pages>")."\n";
                break;

            case self::msgDeliverSuccess:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*no translation of <remote-number>; Dear user,...*/"your document has been successfully delivered to <remote-number>.")."\n\n" .
                    tl::tl(/*no translation of <date>*/"Date <date>")."\n" .
                    tl::tl(/*no translation of <time>*/"Time <time>")."\n" .
                    tl::tl(/*no translation of <remote-subscriber-id>*/"Recipient subscriber ID: <remote-subscriber-id>")."\n" .
                    tl::tl(/*no translation of <pages>*/"Pages: <pages>")."\n" .
                    tl::tl(/*no translation of <duration>*/"Duration: <duration>")."\n";
                break;
                
            case self::msgDeliverError:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*no translation of <remote-number>; Dear user,...*/"your document to <remote-number> could not be delivered.")."\n\n" .
                    tl::tl(/*no translation of <calls>*/"Call attempts: <calls>")."\n" .
                    tl::tl(/*no translation of <error-cause>*/"Error cause: <error-cause>")."\n" .
                    tl::tl(/*no translation of <error-description>*/"Error description: <error-description>")."\n";
                break;
                
            case self::msgDeliverErrorTimeout:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*Dear user,...*/"your document to <remote-number> could not be delivered.")."\n\n" .
                    tl::tl("The remote station has not answered the call.")."\n" .
                    tl::tl(/*no translation of <calls>*/"It was tried <calls> times.")."\n";
                break;
                
            case self::msgDeliverErrorNoFaxDevice:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*Dear user,...*/"your document to <remote-number> could not be delivered.")."\n\n" .
                    tl::tl("The remote station has answered the call, but it is no FAX device.")."\n" .
                    tl::tl(/*no translation of <calls>*/"It was tried <calls> times.")."\n";
                break;
                
            case self::msgDeliverErrorBusy:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*no translation of <remote-number>; Dear user,...*/"your document to <remote-number> could not be delivered.")."\n\n" .
                    tl::tl("The called party is busy.")."\n" .
                    tl::tl(/*no translation of <calls>*/"It was tried <calls> times.")."\n";
                break;

            case self::msgDeliverErrorCanceled:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*no translation of <remote-number>; Dear user,...*/"your document to <remote-number> is not delivered.")."\n\n" .
                    tl::tl("The fax job was canceled by the admin.")."\n";
                break;
            
            case self::msgError:
                $ret = tl::tl("Sorry,")."\n\n" .
                    tl::tl(/*Sorry,...*/"an error occured.")."\n";
                break;
                
            case self::msgErrorRightsNoUser:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"your email address could not be found in the PBX.") . " " .
                    tl::tl("Please contact your administrator to solve this issue.") . "\n";
                break;

            case self::msgErrorRightsNoLicense:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*Dear user,...*/"you haven't got rights to send or receive fax documents.") . " " .
                    tl::tl("Please contact your administrator to solve this issue.") . "\n";
                break;

            case self::msgErrorRightsCheckFailed:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*Dear user,...*/"the rights to send or receive fax documents could not be checked.") . " " .
                    tl::tl("This might be a temporary problem.") . " " .
                    tl::tl("Please try again in a few minutes.") . " " .
                    tl::tl("Should the problem persist, please contact your administrator.") . "\n\n" .
                    tl::tl("Please try again.") . "\n";
                break;
            
            case self::msgErrorNoFaxRecipients:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n".
                    tl::tl(/*Dear user,...*/"there are no fax recipients in the 'To' or 'Cc' recipient lists.") . "\n";
                break;
 
           case self::msgErrorCommand:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"an error occured during command processing.")."\n\n" .
                    tl::tl(/*no translation of <command>*/"Command: <command>")."\n" .
                    tl::tl(/*no translation of <return-code>*/"Return code: <return-code>")."\n" .
                    tl::tl("Command output:")."\n" .
                    "<output>";
                break;
                
            case self::msgErrorJodconverter:
            case self::msgErrorUnoconv:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"your attachment '<attachment>' could not be converted.")."\n\n" .
                    tl::tl(/*no translation of <command>*/"Command: <command>")."\n" .
                    tl::tl(/*no translation of <return-code>*/"Return code: <return-code>")."\n" .
                    tl::tl("Command output:")."\n" .
                    "<output>";
                break;

            case self::msgErrorGhostscript:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"an error occurs during converting the attachment(s) with ghostscript.")."\n\n" .
                    tl::tl(/*no translation of <command>*/"Command: <command>")."\n" .
                    tl::tl(/*no translation of <return-code>*/"Return code: <return-code>")."\n" .
                    tl::tl("Command output:")."\n" .
                    "<output>";
                break;
            
            case self::msgErrorCp:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"the document could not be copied.")."\n\n" .
                    tl::tl(/*no translation of <command>*/"Command: <command>")."\n" .
                    tl::tl(/*no translation of <return-code>*/"Return code: <return-code>")."\n" .
                    tl::tl("Command output:")."\n" .
                    "<output>";
                break;
                
            case self::msgErrorZip:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"an error occurs during working on the Zip archive.")."\n\n" .
                    tl::tl(/*no translation of <step>*/"Step: <step>")."\n" .
                    tl::tl(/*no translation of <return-code>*/"Return code: <return-code>")."\n" .
                    tl::tl(/*no translation of <status>*/"Status: <status>")."\n";
                break;
                
            case self::msgErrorOpenOffice:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"OpenOffice could not be started.")." " .
                    tl::tl("Please try again.")."\n";
                break;

            case self::msgErrorNoAttachment:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*Dear user,...*/"there is no attachment included in the email.")."\n";
                break;
                
            case self::msgErrorReadAttachment:
                $ret = tl::tl(/*no translation of <user-name>*/"Dear <user-name>,")."\n\n" .
                    tl::tl(/*no translation of <attachment>; Dear user,...*/"your Attachment '<attachment>' could not be read.")."\n\n";
                break;
                
            case self::msgErrorMailSend:
                $ret = tl::tl("Dear admin").",\n\n" .
                    tl::tl(/*Dear admin,...*/"could not send email to user.")."\n\n" .
                    tl::tl(/*no translation of <user-name>*/"User: <user-name>")."\n" .
                    tl::tl(/*no translation of <file-name>*/"File name: <file-name>")."\n";
                break;

            case self::msgErrorNoEmailAddress:
                $ret = tl::tl("Dear admin").",\n\n" .
                    tl::tl(/*Dear admin,..."*/"there is no email address configured for the user.")."\n" .
                    tl::tl("The incoming fax call was rejected.")."\n\n" .
                    tl::tl(/*no translation of <user-name>*/"User: <user-name>")."\n" .
                    tl::tl(/*no translation of <remote-number>*/"Caller number: <remote-number>")."\n";
                break;
                
            case self::msgErrorIncoming:
                $ret = tl::tl("Failed incoming fax document");
                break;
                
            case self::msgUnknownUser:
                $ret = tl::tl("user");
                break;
                
            default:
                $ret = "";
                break;
        }
        return $ret;
    }
}

class FaxServer
{
    /**
     *
     * @var integer database id
     */
    var $id = 0;
    /**
     *
     * @var string unique name of the fax server
     */
    var $name = "";
    /**
     *
     * @var boolean server active or not
     */
    var $active = true;
    /**
     *
     * @var string description of the server
     */
    var $desc = "";
    /**
     * @var integer shared memory id
     */
    var $shmId = 0;
    /**
     * @var string webdav URL
     */
    var $webdavURL = null;
    /**
     * @var string Language of mail strings 
     */
    var $lang = "en";
    /**
     * @var string  
     */
    var $faxSubscriberId = "";
    /**
     * @var string  
     */
    var $faxSubscriberIdAlt = "";
    /**
     * @var string  
     */
    var $faxSubscriberName = "";
    /**
     * @var boolean 
     */
    var $faxAddUserNumber = false;
    /**
     * @var string 
     */
    var $faxUserNumberPrefix = "";
    /**
     * @var integer 
     */
    var $faxMaxCallTries = 3;
    /**
     * @var integer in minutes
     */
    var $faxResendDelay = 5; // min
    /**
     * @var integer in seconds
     */
    var $faxResponseTimeout = 60; // sec
    /**
     * @var integer in minutes
     */
    var $faxRetryTimeout = 240; // min
    const fileFormatPDF = "PDF", fileFormatTIFF = "TIFF";
    /**
     *
     * @var string 
     */
    var $faxForwardedFileFormat = self::fileFormatPDF;
    /**
     * @var boolean 
     */
    var $faxCoverIncludesUserText = true;
    /**
     * @var boolean 
     */
    var $faxConfirmationWithDoc = false;
    /**
     *
     * @var string 
     */
    var $mailHost = "127.0.0.1";
    /**
     *
     * @var string
     */
    var $mailPort = 995;
    /**
     *
     * @var string
     */
    var $mailUser = "";
    /**
     *
     * @var string
     */
    var $mailPassword = "";
    /**
     *
     * @var string
     */
    var $mailFolder = "INBOX";
    /**
     *
     * @var string
     */
    var $mailAdmin = "";
    /**
     *
     * @var boolean
     */
    var $mailSAPCode = false;
    /**
     *
     * @var string
     */
    var $faxServerDomain = "";
    /**
     *
     * @var string
     */
    var $soapHost = "";
    /**
     *
     * @var integer
     */
    var $soapPort = null;
    /**
     *
     * @var string
     */
    var $soapUser = "";
    /**
     *
     * @var string
     */
    var $soapPassword = "";
    /**
     *
     * @var string
     */
    var $soapFaxUser = "";
    /**
     *
     * @var string 
     */
    var $soapDynPbx = "";

    /**
     *
     * @var string 
     */
    var $linuxIP = "";
    /**
     *
     * @var integer 
     */
    var $linuxPort = "";
    
    /**
     * @var array of strings
    */
    var $strings = array();
    
    /**
     *
     * @var array of FaxLocation 
     */
    var $locations = array();
    /**
     *
     * @var string error if read/write fails
     */
    var $error = "";
    /**
     *
     * @var string the language in which strings shall be returned/translated
     */
    var $stringLanguage = "en";
    /**
     *
     * @var string cover, which will be used for default text
     */
    var $cover = FaxConfig::coverDefault;//."/innovaphone-default.odt";
    /**
     *
     * @var boolean switches https on/off
     */
    var $https = false;
    /**
     *
     * @var boolean switches tracing on/off
     */
    var $trace = false;
    
    /**
     *
     * @var string
     */
    var $modemSpeed = "";
    const modemSpeedV17 = "V17", modemSpeedV29 = "V29", modemSpeedV27 = "V27";
    
    public function FaxServer() {
        $this->modemSpeed = self::modemSpeedV17;
        $this->updateWebdavURL();
    }
    
    /**
     *
     * @param string $name name of the server to read
     * @param integer $id id of the server to read
     */
    public function read($name = "", $id = 0, InnovaphoneFaxDatabase &$db = null) {
        if($db == null) {
            $db = new InnovaphoneFaxDatabase();
        }
        $this->name = $name;
        $this->id = $id;
        $db->getFaxServer($this);
        $this->updateWebdavURL();
    }
    
    public function start() {
        if($this->id > 0 && $this->active) {
            $out = main_system("ps auxwww | grep -v \"grep\" | egrep -e \"php5.*(innovaphone.fax.pbx.poll.php|innovaphone.fax.mailbox.poll.php) {$this->id}$\"", $ret);
            if($out == "") {    // not already running?
                exec("/usr/bin/setsid /usr/bin/php5 ".FaxConfig::scriptPath."/innovaphone.fax.pbx.poll.php {$this->id} &>>".FaxConfig::logPath."/{$this->id}-pbxpoll.log 2>&1 &");
                exec("/usr/bin/setsid /usr/bin/php5 ".FaxConfig::scriptPath."/innovaphone.fax.mailbox.poll.php {$this->id} &>>".FaxConfig::logPath."/{$this->id}-mailpoll.log 2>&1 &");
            }
        }
    }
    
    public function stop() {
        if($this->id > 0) {
            self::stopId($this->id);
        }
    }
    
    public static function stopId($id) {
        $idStr = ($id == 0 ? ".*" : $id);
        $cmd = "ps auxwww | grep -v \"grep\" | egrep -e \"php5.*(innovaphone.fax.pbx.poll.php|innovaphone.fax.mailbox.poll.php) $idStr$\"";
        $out = main_system($cmd, $ret);
        if($out != "") {
            exec("$cmd | awk '{print $2}' | xargs kill");
            $maxWait = 122;
            while($out != "" && $maxWait > 0) {
                sleep(1);
                $maxWait--;
                $cmd = "ps auxwww | grep -v \"grep\" | egrep -e \"php5.*(innovaphone.fax.pbx.poll.php|innovaphone.fax.mailbox.poll.php) $idStr$\"";
                $out = main_system($cmd, $ret);
            }
            if($out != "") {
                exec("$cmd | awk '{print $2}' | xargs kill -9");
            }
        }
    }
    
    public function restart() {
        global $path;
        $script     = $path . DIRECTORY_SEPARATOR . "innovaphone.fax.convert.out.php";
        exec("/usr/bin/setsid /usr/bin/php5 ".FaxConfig::scriptPath."/../servers.php restart {$this->id} &>>".FaxConfig::logPath."/{$this->id}-restart.log 2>&1 &");
    }
    
    public function write(InnovaphoneFaxDatabase &$db = null) {
        if($db == null) {
            $db = new InnovaphoneFaxDatabase();
        }
        if($db->writeFaxServer($this) === false) {
            $this->error = $db->error;
            return false;
        }
        return true;
    }
    
    public function writeStrings($lang, InnovaphoneFaxDatabase &$db = null) {
        if($db == null) {
            $db = new InnovaphoneFaxDatabase();
        }
        if($db->writeFaxServerStrings($this, $lang) === false) {
            $this->error = $db->error;
            return false;
        }
        return true;
    }
    
    public function updateWebdavURL() {
        // if this is changed, it must also changed in java.js javascript function updateWebDAVInfo
        global $mainSession;
        $https = $mainSession->webCfg->forceHttps || $this->https;
        $linuxIP = $this->linuxIP != "" ? $this->linuxIP : get_dhcp_address();
        $this->webdavURL = "http" . ($https ? "s" : "") . "://" . $linuxIP . ($this->linuxPort != 0 ? (":" . $this->linuxPort) : "") . "/webdav/faxserver";
    }
    
    public function getLocationLanguage($name) {
        foreach($this->locations as $loc) {
            if($loc->name == $name) {
                return $loc->lang;
            }
        }
        return $this->lang;
    }
    
    private function formatString($string) {
        $stringParts = explode("\n", $string);
        foreach($stringParts as &$part) {
            $part = tl::tl($part);
        }
        return implode("\n", $stringParts);
    }
    
    private function changeLanguage($lang) {
        tl::change($lang);
        if(tl::currentLanguage() != $lang) {
            tl::change("en");
        }
    }
    
    public function getString($id, $lang, $useDbStrings = true) {
        $curLang = tl::currentLanguage();
        $string = "";
        if($useDbStrings && isset($this->strings[$lang][$id])) {
            $this->changeLanguage($lang);
            $string = $this->formatString($this->strings[$lang][$id]);
        }
        else {
            $this->changeLanguage($lang);
            $string = FaxServerStrings::getString($id);
        }
        tl::change($curLang);
        return $string;
    }
    
    public function coverPrefix() {
        return "_{$this->id}_";
    }
    
    public function getCovers($addEmpty = false) {
        $covers = array();
        if($addEmpty) {
            $covers[""] = "";
        }
        $handle=opendir (FaxConfig::coverPath);
        while ($cover = readdir ($handle)) {
            if(is_file(FaxConfig::coverPath."/".$cover)) {
                if(strpos($cover, $this->coverPrefix()) === 0) {
                    $coverName = str_replace($this->coverPrefix(), "", $cover);
                    $covers[$coverName] = $coverName;
                }
            }
        }
        closedir($handle);
        $covers[FaxConfig::coverDefault] = str_replace("/var/www/innovaphone/apps/innovaphone-faxserver/", "", FaxConfig::coverDefault);
        return $covers;
    }
    
    public function coverPath($location = "", $cover = "") {
        if($location != "") {
            foreach($this->locations as $loc) {
                if($loc->name == $location) {
                    $cover = $loc->cover;
                    break;
                }
            }
        }
        $c = ($cover == "" ? $this->cover : $cover);
        if($c == FaxConfig::coverDefault || $c == FaxConfig::coverDefaultName) return FaxConfig::coverDefault;
        else if($c != "") return FaxConfig::coverPath."/".$this->coverPrefix().$c;
        return "";
    }
    
    public function setModemSpeed($speed) {
        if($speed == "" || $speed == null) {
            $this->modemSpeed = self::modemSpeedV17;
        }
        else {
            $this->modemSpeed = $speed;
        }
    }
    
    public function setForwardedFileFormat($format) {
        if($format == self::fileFormatPDF || $format == self::fileFormatTIFF) {
            $this->faxForwardedFileFormat = $format;
        }
        else {
            $this->faxForwardedFileFormat = self::fileFormatPDF;
        }
    }
}

?>
